/**
  * ----------------------------------------------------------------
  * Copyright (C)   Endress&Hauser GmbH (2000). All Rights Reserved.
  * Product:        SIMATIC SIPROM
  * Device:         Level Device for Profibus PA
  *                 MICROPILOT FMR 23x (V2.0)
  * Description:    Electronic Device Description (EDD)
  * Dictionary:     SIPADC01.dct
  * $Revision:1.34$									
  * $Date: 06.02.2002									
  * Obere Revision fr QVCS, untere fr DD, unten die aktuelle angeben 			
  * Revision:1.34									
  * Date: 06.02.2002									
  * ----------------------------------------------------------------
  * $Date:          30. Mrz 2001 11:08:29 GMT+01:00 $
  * $Name:          30. Mrz 2001 11:08:29 GMT+01:00 $
  * $Changes:       Defaultwerte gendert, V3H4 nur noch online,aus Upload entfernt$
  *                 herstellerspezifische Parameter aus Profilansicht entfernt *
  */

MANUFACTURER     17,          /* Endress & Hauser */
DEVICE_TYPE      1,
DEVICE_REVISION  1,
DD_REVISION      1

/* ============================================================= */
#define DEFAULT_VALUE_phys_device_id "FMR 23x"
#define DEFAULT_VALUE_phys_software_rev "2.0"
#include "SIPAST_Macros_200.inc"

#define DEFAULT_MANUFACTURER_ID 17
#define CHECK_PROFILE_REV 0x200
#include "SIPAST.inc"

// --- Yt ---------------------------------------------------------

#define YT1_LABEL		[func_out_value]
#define YT1_HELP		[func_ai_out_value_help]
#define YT1_VALUE		func1_out_value
#define	YT1_LRV		func1_out_lower_range_value
#define YT1_URV		func1_out_upper_range_value
#include "SI_YT.inc"


/* ================================================================
 *     Block-Information
 * ================================================================
 */

/* ----------------------------------------------------------------
 *     Physical Block
 * ----------------------------------------------------------------
 */

#include "SIPASTPB_200.inc"
#define DEFAULT_VALUE_func1_lo_lo_lim -3e38
#define DEFAULT_VALUE_func1_lo_lim -3e38
#define DEFAULT_VALUE_func1_hi_lim 3e38
#define DEFAULT_VALUE_func1_hi_hi_lim 3e38
// redefines phys_security_locking from SIPASTPB_200.inc
VARIABLE phys_security_locking 		//V9H9
{
	LABEL		[phys_security_locking];
	HELP		[phys_security_locking_help];
	CLASS		CONTAINED;
	HANDLING	READ & WRITE;
	TYPE		ENUMERATED (2)
	{
		{	0,	[phys_security_locking_0]		},
		{ 333,	[phys_security_locking_333]		},
		{9303,	[phys_security_locking_9303]	}
	}
}
VARIABLE phys_factory_reset /* optional */
{
	LABEL		[phys_factory_reset];
	HELP		[phys_factory_reset_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		{ 333,		[customer_reset]		},	//Kundenreset
		{ 7864, 	[full_reset]			},	//Totalreset
		{ 545, 		[tvg_reset] 			}	//TVG Reset
	}
	HANDLING	WRITE;
}

#define DEF_MATRIX_ERRORS  \
	{0,   [E0]},   \
	{101, [E101]}, \
	{102, [E102]}, \
	{103, [E103]}, \
	{106, [E106]}, \
	{110, [E110]}, \
	{111, [E111]}, \
	{112, [E112]}, \
	{113, [E113]}, \
	{114, [E114]}, \
	{115, [E115]}, \
	{116, [E116]}, \
	{231, [E231]}, \
	{232, [E232]}, \
	{512, [E512]}, \
	{602, [E602]}, \
	{604, [E604]}, \
	{605, [E605]}, \
	{613, [E613]}, \
	{621, [E621]}, \
	{641, [E641]}, \
	{643, [E643]}  \

VARIABLE phys_ms_matrix_err_code
{
	LABEL    [phys_ms_matrix_err_code];
	HELP     [phys_matrix_error_code_help];
	CLASS    CONTAINED;
	HANDLING READ;
	TYPE     ENUMERATED (2)
	{
		DEF_MATRIX_ERRORS
	}
}
COMMAND read_phys_ms_matrix_err_code
{
	BLOCK physical_block;
	INDEX 38;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_ms_matrix_err_code
		}
	}
}

VARIABLE phys_ms_matrix_last_err_code
{
	LABEL    [phys_ms_matrix_last_err_code];
	HELP     [phys_matrix_error_code_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE     ENUMERATED (2)
	{
		DEF_MATRIX_ERRORS
	}
}
COMMAND read_phys_ms_matrix_last_err_code
{
	BLOCK physical_block;
	INDEX 39;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_ms_matrix_last_err_code
		}
	}
}
COMMAND write_phys_ms_matrix_last_err_code
{
	BLOCK physical_block;
	INDEX 39;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_ms_matrix_last_err_code
		}
		REPLY
		{
		}
	}
}

VARIABLE phys_ms_device_bus_address
{
	LABEL    [phys_ms_device_bus_address];
	HELP     [phys_ms_device_bus_address_help];
	CLASS    CONTAINED;
	HANDLING READ;
	TYPE     UNSIGNED_INTEGER (1);
}
COMMAND read_phys_ms_device_bus_address
{
	BLOCK physical_block;
	INDEX 40;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_ms_device_bus_address
		}
	}
}

VARIABLE phys_ms_device_and_software_no
{
	LABEL    [phys_ms_device_and_software_no];
	HELP     [phys_ms_device_and_software_no_help];
	CLASS    CONTAINED;
	HANDLING READ;
	TYPE     UNSIGNED_INTEGER (2);
}
COMMAND read_phys_ms_device_and_software_no
{
	BLOCK physical_block;
	INDEX 44;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_ms_device_and_software_no
		}
	}
}

/* ----------------------------------------------------------------
 *     Transducer Block
 * ----------------------------------------------------------------
 */

#define DEF_ACCESS_711_712													\
	IF ((phys_security_locking == 333)||(phys_security_locking == 9303))	\
	{																		\
		IF (trans1_service_code == 333)										\
		{																	\
			READ;															\
		} ELSE {															\
			IF (trans1_service_code == 1163)								\
			{																\
				READ & WRITE;												\
			} ELSE															\
			{																\
				READ;														\
			}																\
		}																	\
	} ELSE {																\
		READ;																\
	}																		\

#define DEF_ACCESS_71_2_79													\
	IF ((phys_security_locking == 333)||(phys_security_locking == 9303))	\
	{																		\
		IF (trans1_service_code == 333)										\
		{																	\
			READ & WRITE;													\
		} ELSE {															\
			IF (trans1_service_code == 1163)								\
			{																\
				READ & WRITE;												\
			} ELSE															\
			{																\
				READ;														\
			}																\
		}																	\
	} ELSE {																\
		READ;																\
	}																		\


BLOCK transducer_block_1
{
	TYPE	TRANSDUCER;
	NUMBER	1;
}

VARIABLE trans1_blk_reserve
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans1_blk_object
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	3,	[blk_block_object_TRANSDUCER]		}
	}
	HANDLING	READ;
}

VARIABLE trans1_blk_parent_class
{
	LABEL		[blk_parent_class];
	HELP		[trans_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	4;
		{	4,	[trans_blk_parent_class_LEVEL]		}
	}
	HANDLING	READ;
}

VARIABLE trans1_blk_class
{
	LABEL		[blk_class];
	HELP		[trans_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	252;
		{	1,		[trans_lev_blk_class_HYDRO]	},
		{	2,		[trans_lev_blk_class_ECHO]	},
		{	250,	[not_used] 					},
		{	251,	[none]						},
		{	252,	[unknown]					},
		{	253,	[special]					}
	}
	HANDLING	READ;
}

VARIABLE trans1_blk_dd_reference
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE trans1_blk_dd_rev
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_blk_profile
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_blk_profile_rev
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		{	512,	"2.0"	}
	}
	HANDLING	READ;
}

VARIABLE trans1_blk_execution_time
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans1_blk_highest_rel_offset
{
	LABEL		[blk_highest_rel_offset];
	HELP		[blk_highest_rel_offset_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_blk_index_view_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_blk_num_view_lists
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans1_st_rev
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE trans1_tag_desc
{
	LABEL		[tag_desc];
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_strategy
{
	LABEL		[strategy];
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_alert_key
{
	LABEL		[alert_key];
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_target_mode
{
	LABEL		[target_mode];
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO]				}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_actual_mode
{
	LABEL		[actual_mode];
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO]				}
	}
	HANDLING	READ;
}

VARIABLE trans1_permitted_mode
{
	LABEL		[permitted_mode];
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO]				}
	}
	HANDLING	READ;
}

VARIABLE trans1_normal_mode
{
	LABEL		[normal_mode];
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO]				}
	}
	HANDLING	READ;
}

VARIABLE trans1_current_state_alarm_sum
{
	LABEL		[current_state_alarm_sum];
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_unacknowledged_state_alarm_sum
{
	LABEL		[unacknowledged_state_alarm_sum];
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_unreported_state_alarm_sum
{
	LABEL		[unreported_state_alarm_sum];
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_disabled_state_alarm_sum
{
	LABEL		[disabled_state_alarm_sum];
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}


/*---------------------------------------------------------------------*/
/*    Transducer Block: Level Transmitter							   */
/*---------------------------------------------------------------------*/

VARIABLE trans1_volume				//V0H0
{
	LABEL		[trans1_volume];
	HELP		[trans1_volume_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_volume_unit			//VAH3
{
	LABEL		[trans_lev_volume_unit];
	HELP		[trans_lev_volume_unit];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	57;

		{ 57,  [Percent],				[Percent_help]				},
		{ 41,  [liter],					[liter_help]				},
		{ 236, [hecto_liter],			[hecto_liter_help]			},
		{ 43,  [CuMtr],					[CuMtr_help]				},
		{ 112, [CuFt],					[CuFt_help]					},
		{ 40,  [gal],					[gal_help]					},
		{ 42,  [ImpGal],				[ImpGal_help]				},
		{ 61,  [kg],					[kg_help]					},
		{ 62,  [MetTon],				[MetTon_help]				},
		{ 63,  [lb],					[lb_help]					},
		{ 64,  [ShTon],					[ShTon_help]				},
		{ 251, [none]												}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_sensor_high_limit
{
	LABEL		[trans_sensor_upper_limit];
	HELP		[trans_sensor_upper_limit_help];
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_sensor_low_limit
{
	LABEL		[trans_sensor_lower_limit];
	HELP		[trans_sensor_lower_limit_help];
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_level			//V0H9
{
	LABEL		[trans_lev_level];
	HELP		[trans_lev_level_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_zero_offset			//V3H6
{
	LABEL		[trans_lev_zero_offset];
	HELP		[trans_lev_zero_offset_help];
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Level Echo									   */
/*---------------------------------------------------------------------*/

VARIABLE trans1_measure_distance		//V0H8
{
	LABEL		[trans_lev_meas_distance];
	HELP		[trans_lev_meas_distance_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_distance_unit			//V8H2
{
	LABEL		[trans_lev_distance_unit];
	HELP		[trans_lev_distance_unit_help];
	CLASS		CONTAINED ;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	45;
		{ 44,  [ft],			[ft_help]		},
		{ 45,  [meter],			[meter_help]	},
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_empty			//V0H1
{
	LABEL		[trans_lev_empty];
	HELP		[trans_lev_empty_help];
	CLASS		CONTAINED ;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
}

VARIABLE trans1_full			//V0H2
{
	LABEL		[trans_lev_full];
	HELP		[trans_lev_full_help];
	CLASS		CONTAINED ;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
}

VARIABLE trans1_application		//V0H3
{
	LABEL		[trans_lev_application];
	HELP		[trans_lev_application_help];
	CLASS		CONTAINED ;
	TYPE		ENUMERATED (1)
	{
		{	0,	[trans_lev_application_0]		},	//Tank 7m
		{	1,	[trans_lev_application_1]		},	//Tank 1,5m
		{	2,	[trans_lev_application_2]		},	//Tank 7m  er<10
		{	3,	[trans_lev_application_3]		},	//Tank 20m
		{	4,	[trans_lev_application_4]		},	//SW 7m
		{	5,	[trans_lev_application_5]		},	//SW 1,5m
		{	6,	[trans_lev_application_6]		},	//SW 20m
		{	7,	[trans_lev_application_7]		},	//Service 7
		{	8,	[trans_lev_application_8]		},	//Service 8
		{	9,	[trans_lev_application_9]		}	//Service 9
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_echo_quality			//V3H2
{
	LABEL		[trans_lev_echo_quality];
	HELP		[trans_lev_echo_quality_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
	CONSTANT_UNIT "dB";
}

VARIABLE trans1_first_echo_factor		//V3H4
{
	LABEL		[trans_lev_first_echo_factor];
	HELP		[trans_lev_first_echo_factor_help];
	CLASS		CONTAINED ;
	HANDLING	READ & WRITE;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 2;
		{	0,	[trans1_first_echo_factor_0]		},	//MIN
		{	1,	[trans1_first_echo_factor_1]		},	//MEDIUM
		{	2,	[trans1_first_echo_factor_2]		}	//MAX
	}
}

/***********************************************************************/
/*    COMMANDS			                                               */
/***********************************************************************/

COMMAND read_trans1_blk
{
	BLOCK transducer_block_1;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_blk_reserve, trans1_blk_object, trans1_blk_parent_class, trans1_blk_class,
			trans1_blk_dd_reference, trans1_blk_dd_rev, trans1_blk_profile, trans1_blk_profile_rev,
			trans1_blk_execution_time, trans1_blk_highest_rel_offset, trans1_blk_index_view_1,
			trans1_blk_num_view_lists
		}
	}
}

COMMAND read_trans1_st_rev
{
	BLOCK transducer_block_1;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_st_rev
		}
	}
}

COMMAND read_trans1_tag_desc
{
	BLOCK transducer_block_1;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_tag_desc
		}
	}
}

COMMAND write_trans1_tag_desc
{
	BLOCK transducer_block_1;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_tag_desc
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_strategy
{
	BLOCK transducer_block_1;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_strategy
		}
	}
}

COMMAND write_trans1_strategy
{
	BLOCK transducer_block_1;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_strategy
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_alert_key
{
	BLOCK transducer_block_1;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_alert_key
		}
	}
}

COMMAND write_trans1_alert_key
{
	BLOCK transducer_block_1;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_alert_key
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_target_mode
{
	BLOCK transducer_block_1;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_target_mode
		}
	}
}

COMMAND write_trans1_target_mode
{
	BLOCK transducer_block_1;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_target_mode
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_mode
{
	BLOCK transducer_block_1;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 trans1_actual_mode, trans1_permitted_mode, trans1_normal_mode
		}
	}
}

COMMAND read_trans1_alarm
{
	BLOCK transducer_block_1;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_current_state_alarm_sum, trans1_unacknowledged_state_alarm_sum,
			trans1_unreported_state_alarm_sum, trans1_disabled_state_alarm_sum
		}
	}
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Level Transmitter							   */
/*---------------------------------------------------------------------*/

COMMAND read_trans1_volume
{
	BLOCK transducer_block_1;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_volume
		}
	}
}

COMMAND read_trans1_volume_unit
{
	BLOCK transducer_block_1;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_volume_unit
		}
	}
}

COMMAND write_trans1_volume_unit
{
	BLOCK transducer_block_1;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_volume_unit
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_sensor_high_limit
{
	BLOCK transducer_block_1;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_sensor_high_limit
		}
	}
}

COMMAND read_trans1_sensor_low_limit
{
	BLOCK transducer_block_1;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_sensor_low_limit
		}
	}
}

COMMAND read_trans1_level
{
	BLOCK transducer_block_1;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_level
		}
	}
}

COMMAND read_trans1_zero_offset
{
	BLOCK transducer_block_1;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_zero_offset
		}
	}
}

COMMAND write_trans1_zero_offset
{
	BLOCK transducer_block_1;
	INDEX 17;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_zero_offset
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_measure_distance
{
	BLOCK transducer_block_1;
	INDEX 37;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_measure_distance
		}
	}
}

COMMAND read_trans1_distance_unit
{
	BLOCK transducer_block_1;
	INDEX 38;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_distance_unit
		}
	}
}

COMMAND write_trans1_distance_unit
{
	BLOCK transducer_block_1;
	INDEX 38;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_distance_unit
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_empty
{
	BLOCK transducer_block_1;
	INDEX 39;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_empty
		}
	}
}

COMMAND write_trans1_empty
{
	BLOCK transducer_block_1;
	INDEX 39;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_empty
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_full
{
	BLOCK transducer_block_1;
	INDEX 40;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_full
		}
	}
}

COMMAND write_trans1_full
{
	BLOCK transducer_block_1;
	INDEX 40;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_full
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_application
{
	BLOCK transducer_block_1;
	INDEX 44;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_application
		}
	}
}

COMMAND write_trans1_application
{
	BLOCK transducer_block_1;
	INDEX 44;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_application
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_echo_quality
{
	BLOCK transducer_block_1;
	INDEX 45;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_echo_quality
		}
	}
}

COMMAND read_trans1_first_echo_factor
{
	BLOCK transducer_block_1;
	INDEX 46;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_first_echo_factor
		}
	}
}

COMMAND write_trans1_first_echo_factor
{
	BLOCK transducer_block_1;
	INDEX 46;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_first_echo_factor
		}
		REPLY
		{
		}
	}
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: manufacturer specificals					   */
/*---------------------------------------------------------------------*/

VARIABLE trans1_damping			//V0H4
{
	LABEL    [trans1_damping];
	HELP     [trans1_damping_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE     FLOAT;
	CONSTANT_UNIT [sec];
}
COMMAND read_trans1_damping
{
	BLOCK transducer_block_1;
	INDEX 55;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_damping
		}
	}
}
COMMAND write_trans1_damping
{
	BLOCK transducer_block_1;
	INDEX 55;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_damping
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_fail_safe		//V0H7
{
	LABEL    [trans1_fail_safe];
	HELP     [trans1_fail_safe_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE	 ENUMERATED (1)
	{
		{	1,	[trans1_fail_safe_1]		},	//MIN
		{	0,	[trans1_fail_safe_0]		},	//MAX
		{	239,[trans1_fail_safe_239]		}	//HOLD
	}

}
COMMAND read_trans1_fail_safe
{
	BLOCK transducer_block_1;
	INDEX 56;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_fail_safe
		}
	}
}
COMMAND write_trans1_fail_safe
{
	BLOCK transducer_block_1;
	INDEX 56;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_fail_safe
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_lin_mode			//V2H0
{
	LABEL    [trans1_lin_mode];
	HELP     [trans1_lin_mode_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE	 ENUMERATED (1)
	{
		{	240,	[trans1_lin_mode_level]			},	// LEVEL
		{	4,		[trans1_lin_mode_activate_table]},	// ACTIVATE_TABLE
		{	241,	[trans1_lin_mode_manual_input]	},	// MANUAL_INPUT
		{	242,	[trans1_lin_mode_semiautomatic]	},	// SEMIAUTOMATIC
		{	243,	[trans1_lin_mode_clear]			},	// CLEAR
		{	0,		[trans1_lin_mode_linear]		}	// LINEAR
	}
}
COMMAND read_trans1_lin_mode
{
	BLOCK transducer_block_1;
	INDEX 57;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lin_mode
		}
	}
}
COMMAND write_trans1_lin_mode
{
	BLOCK transducer_block_1;
	INDEX 57;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_lin_mode
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_lintab_no			//V2H1
{
	LABEL    [trans1_lintab_no];
	HELP     [trans1_lintab_no_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE     UNSIGNED_INTEGER (1);
}
COMMAND read_trans1_lintab_no
{
	BLOCK transducer_block_1;
	INDEX 58;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lintab_no
		}
	}
}
COMMAND write_trans1_lintab_no
{
	BLOCK transducer_block_1;
	INDEX 58;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_lintab_no
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_lintab_level			//V2H2
{
	LABEL    [trans1_lintab_level];
	HELP     [trans1_lintab_level_help];
	CLASS    CONTAINED;
	HANDLING IF (trans1_lin_mode == 241)
			{
				READ & WRITE;
			}
			ELSE
			{
				READ;
			}
	TYPE     FLOAT;
}
COMMAND read_trans1_lintab_level
{
	BLOCK transducer_block_1;
	INDEX 59;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lintab_level
		}
	}
}
COMMAND write_trans1_lintab_level
{
	BLOCK transducer_block_1;
	INDEX 59;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			IF (trans1_lin_mode == 241)
			{
				trans1_lintab_level
			}
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_lintab_volume			//V2H3
{
	LABEL    [trans1_lintab_volume];
	HELP     [trans1_lintab_volume_help];
	CLASS    CONTAINED;
	HANDLING
			IF (trans1_lin_mode == 241)
			{
				READ & WRITE;
			} ELSE {
				READ;
			}
	TYPE     FLOAT;
}
COMMAND read_trans1_lintab_volume
{
	BLOCK transducer_block_1;
	INDEX 60;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lintab_volume
		}
	}
}
COMMAND write_trans1_lintab_volume
{
	BLOCK transducer_block_1;
	INDEX 60;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_lintab_volume
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_max_volume				//V2H5
{
	LABEL    [trans1_max_volume];
	HELP     [trans1_max_volume_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE     FLOAT;
}
COMMAND read_trans1_max_volume
{
	BLOCK transducer_block_1;
	INDEX 61;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_max_volume
		}
	}
}
COMMAND write_trans1_max_volume
{
	BLOCK transducer_block_1;
	INDEX 61;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_max_volume
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_false_echo_suppression			//V3H0
{
	LABEL    [trans1_false_echo_suppression];
	HELP     [trans1_false_echo_suppression_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE	 ENUMERATED (1)
	{
		{	0,	[trans1_false_echo_suppression_0]		},	//FACTORY
		{	1,	[trans1_false_echo_suppression_1]		},	//CUSTOMER
		{	2,	[trans1_false_echo_suppression_2]		},	//UP TO ECHO
		{	3,	[trans1_false_echo_suppression_3]		},	//INCL. ECHO
		{	4,	[trans1_false_echo_suppression_4]		}	//TO DISTANCE
	}
}

METHOD meth_v3_transmit
{
	LABEL	[transfer];
	HELP	[transfer_help];
	DEFINITION
	{
		int v30;
		long i;
		int ret;
		int abb;
		float f1, f2;
		long v3h1unit[1];

		v30=ivar_value(trans1_false_echo_suppression);

		// in jedem Fall v30 = 0 runterschreiben
		iassign(trans1_false_echo_suppression, 0);
		WriteCommand(write_trans1_false_echo_suppression);

		if (0!=v30)
		{

			//	wait();
			ACKNOWLEDGE([txt_my_wait]);

			ReadCommand(read_trans1_suppression_distance);
			f1=fvar_value(trans1_suppression_distance);
			_TRACE(f1);

			iassign(trans1_false_echo_suppression, v30);
			WriteCommand(write_trans1_false_echo_suppression);
			if (1!=v30)
			{
				i=0;
				abb=0;

				while (abb==0)
				{
					i++;
					ReadCommand(read_trans1_suppression_distance);
					f2=fvar_value(trans1_suppression_distance);
					_TRACE(f2);

					if ((i>100)||(f1!=f2))
					{
						abb=1;
					}
				}
			}
		}

		if ((2==v30)||(3==v30)||(4==v30))
		{
			v3h1unit[0] = VARID(trans1_distance_unit);
			ReadCommand(read_trans1_suppression_distance);
			ret = get_dev_var_value([ack_choice_suppression_distance], v3h1unit, trans1_suppression_distance);
			WriteCommand(write_trans1_suppression_distance);
		}
	}
}

COMMAND read_trans1_false_echo_suppression
{
	BLOCK transducer_block_1;
	INDEX 62;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_false_echo_suppression
		}
	}
}
COMMAND write_trans1_false_echo_suppression
{
	BLOCK transducer_block_1;
	INDEX 62;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_false_echo_suppression
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_suppression_distance		//V3H1
{
	LABEL    [trans1_suppression_distance];
	HELP     [trans1_suppression_distance_help];
	CLASS    CONTAINED;
	HANDLING
			IF (4 == trans1_false_echo_suppression)
			{
				READ & WRITE;
			} ELSE {
				READ;
			}
	TYPE     FLOAT;
}

COMMAND read_trans1_suppression_distance
{
	BLOCK transducer_block_1;
	INDEX 63;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_suppression_distance
		}
	}
}
COMMAND write_trans1_suppression_distance
{
	BLOCK transducer_block_1;
	INDEX 63;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_suppression_distance
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_microfactor			//V3H3
{
	LABEL    [trans1_microfactor];
	HELP     [trans1_microfactor_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE     FLOAT;
}
COMMAND read_trans1_microfactor
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_microfactor
		}
	}
}
COMMAND write_trans1_microfactor
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_microfactor
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_window_suppression		//V3H5
{
	LABEL    [trans1_window_suppression];
	HELP     [trans1_window_suppression_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE     FLOAT;
}
COMMAND read_trans1_window_suppression
{
	BLOCK transducer_block_1;
	INDEX 65;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_window_suppression
		}
	}
}
COMMAND write_trans1_window_suppression
{
	BLOCK transducer_block_1;
	INDEX 65;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_window_suppression
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_service_layer      //V7H0
{
	LABEL    [txt_service_layer];
	HELP     [txt_service_layer];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE     UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 251;
	}
}
COMMAND read_trans1_service_layer
{
	BLOCK transducer_block_1;
	INDEX 66;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_service_layer
		}
	}
}
COMMAND write_trans1_service_layer
{
	BLOCK transducer_block_1;
	INDEX 66;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_service_layer
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_z_distance      //V7H1
{
	LABEL    [txt_z_distance];
	HELP     [txt_z_distance];
	CLASS    CONTAINED & DYNAMIC;
	HANDLING DEF_ACCESS_71_2_79
	TYPE     FLOAT
	{
		DEFAULT_VALUE 0.0;
		MIN_VALUE 0.0;
		MAX_VALUE 20.0;
	}
	VALIDITY
	IF (trans1_service_layer == 0)
	{
		TRUE;
	} ELSE {
		FALSE;
	}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H1
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H1
	}
}
METHOD meth_update_std_V7H1
{
	DEFINITION
	{
		std_V7H1=fvar_value(trans1_z_distance);
	}
}

COMMAND read_trans1_z_distance
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_z_distance
		}
	}
}
COMMAND write_trans1_z_distance
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_z_distance
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_length_of_antenna			//V7H2
{
	LABEL    [txt_length_of_antenna];
	HELP     [txt_length_of_antenna];
	CLASS    CONTAINED & DYNAMIC;
	HANDLING DEF_ACCESS_71_2_79
	TYPE     FLOAT
	{
		DEFAULT_VALUE 0.0;
		MIN_VALUE -20.0;
		MAX_VALUE 20.0;
	}
	VALIDITY
		IF (trans1_service_layer == 0)
		{
			TRUE;
		} ELSE {
			FALSE;
		}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H2
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H2
	}
}
METHOD meth_update_std_V7H2
{
	DEFINITION
	{
		std_V7H2=fvar_value(trans1_length_of_antenna);
	}
}
COMMAND read_trans1_length_of_antenna
{
	BLOCK transducer_block_1;
	INDEX 68;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_length_of_antenna
		}
	}
}
COMMAND write_trans1_length_of_antenna
{
	BLOCK transducer_block_1;
	INDEX 68;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_length_of_antenna
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_modul_type           //V7H3
{
	LABEL    [txt_modul_type];
	HELP     [txt_modul_type];
	CLASS    CONTAINED & DYNAMIC;
	HANDLING DEF_ACCESS_71_2_79
	TYPE     UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 0;
	}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H3
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H3
	}
}
METHOD meth_update_std_V7H3
{
	DEFINITION
	{
		std_V7H3=ivar_value(trans1_modul_type);
	}
}

COMMAND read_trans1_modul_type
{
	BLOCK transducer_block_1;
	INDEX 69;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_modul_type
		}
	}
}
COMMAND write_trans1_modul_type
{
	BLOCK transducer_block_1;
	INDEX 69;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_modul_type
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_record_tvg			//V7H4
{
	LABEL    [txt_record_tvg];
	HELP     [txt_record_tvg];
	CLASS    CONTAINED & DYNAMIC;
	HANDLING DEF_ACCESS_71_2_79
	TYPE     ENUMERATED (1)
	{
		DEFAULT_VALUE 0;
		{0,	[txt_customer_tvg],	[txt_customer_tvg_help]},
		{1, [txt_factory_tvg],	[txt_factory_tvg_help]}
	}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H4
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H4
	}
}
METHOD meth_update_std_V7H4
{
	DEFINITION
	{
		std_V7H4=ivar_value(trans1_record_tvg);
	}
}

COMMAND read_trans1_record_tvg
{
	BLOCK transducer_block_1;
	INDEX 70;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_record_tvg
		}
	}
}
COMMAND write_trans1_record_tvg
{
	BLOCK transducer_block_1;
	INDEX 70;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_record_tvg
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_service_data_75			//V7H5
{
	LABEL    [trans1_service_data_75];
	HELP     [trans1_service_data_75];
	CLASS    CONTAINED & DYNAMIC;
	HANDLING READ;
	TYPE     FLOAT
	{
		DEFAULT_VALUE 0.0;
	}
	VALIDITY
		IF (trans1_service_layer == 0)
		{
			TRUE;
		} ELSE {
			FALSE;
		}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H5
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H5
	}
}
METHOD meth_update_std_V7H5
{
	DEFINITION
	{
		std_V7H5=fvar_value(trans1_service_data_75);
	}
}

COMMAND read_trans1_service_data_75
{
	BLOCK transducer_block_1;
	INDEX 71;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_service_data_75
		}
	}
}

VARIABLE trans1_service_data_76			//V7H6
{
	LABEL    [trans1_service_data_76];
	HELP     [trans1_service_data_76];
	CLASS    CONTAINED & CONTAINED;
	HANDLING DEF_ACCESS_71_2_79
	TYPE     FLOAT
	{
		DEFAULT_VALUE 3;
	}
	CONSTANT_UNIT "dB";
	VALIDITY
		IF (trans1_service_layer == 0)
		{
			TRUE;
		} ELSE {
			FALSE;
		}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H6
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H6
	}
}
METHOD meth_update_std_V7H6
{
	DEFINITION
	{
		std_V7H6=fvar_value(trans1_service_data_76);
	}
}
COMMAND read_trans1_service_data_76
{
	BLOCK transducer_block_1;
	INDEX 72;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_service_data_76
		}
	}
}
COMMAND write_trans1_service_data_76
{
	BLOCK transducer_block_1;
	INDEX 72;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_service_data_76
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_service_data_77		//V7H7
{
	LABEL    [trans1_service_data_77];
	HELP     [trans1_service_data_77];
	CLASS    CONTAINED & DYNAMIC;
	HANDLING DEF_ACCESS_71_2_79
	TYPE     FLOAT
	{
		DEFAULT_VALUE 20.5;
	}
	VALIDITY
		IF (trans1_service_layer == 0)
		{
			TRUE;
		} ELSE {
			FALSE;
		}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H7
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H7
	}
}
METHOD meth_update_std_V7H7
{
	DEFINITION
	{
		std_V7H7=fvar_value(trans1_service_data_77);
	}
}

COMMAND read_trans1_service_data_77
{
	BLOCK transducer_block_1;
	INDEX 73;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_service_data_77
		}
	}
}
COMMAND write_trans1_service_data_77
{
	BLOCK transducer_block_1;
	INDEX 73;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_service_data_77
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_service_data_78				//V7H8
{
	LABEL    [trans1_service_data_78];
	HELP     [trans1_service_data_78];
	CLASS    CONTAINED & DYNAMIC;
	HANDLING READ;
	TYPE     FLOAT
	{
		DEFAULT_VALUE 0.0;
	}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H8
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H8
	}
}
METHOD meth_update_std_V7H8
{
	DEFINITION
	{
		std_V7H8=fvar_value(trans1_service_data_78);
	}
}

COMMAND read_trans1_service_data_78
{
	BLOCK transducer_block_1;
	INDEX 74;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_service_data_78
		}
	}
}

VARIABLE trans1_service_code			//V7H9
{
	LABEL    [trans1_service_code];
	HELP     [trans1_service_code];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE     UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE 9999;
		MIN_VALUE 0;
		MAX_VALUE 9999;
	}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H9
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H9
	}
}
METHOD meth_update_std_V7H9
{
	DEFINITION
	{
		std_V7H9=ivar_value(trans1_service_code);
	}
}
COMMAND read_trans1_service_code
{
	BLOCK transducer_block_1;
	INDEX 75;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_service_code
		}
	}
}
COMMAND write_trans1_service_code
{
	BLOCK transducer_block_1;
	INDEX 75;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_service_code
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_display_min				//V8H1
{
	LABEL    [trans1_display_min];
	HELP     [trans1_display_min_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE	 ENUMERATED (1)
	{
		DEFAULT_VALUE 1;
		{	0,	[trans1_display_min_0]		},	//OFF
		{	1,	[trans1_display_min_1]		}	//ON
	}
}
COMMAND read_trans1_display_min
{
	BLOCK transducer_block_1;
	INDEX 76;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_display_min
		}
	}
}
COMMAND write_trans1_display_min
{
	BLOCK transducer_block_1;
	INDEX 76;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_display_min
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_echo_alarm_delay				//V8H3
{
	LABEL		[trans_lev_echo_alarm_delay];
	HELP		[trans_lev_echo_alarm_delay_help];
	CLASS		CONTAINED ;
	TYPE		UNSIGNED_INTEGER (2);
	CONSTANT_UNIT	[sec];
	HANDLING	READ & WRITE;
}
COMMAND read_trans1_echo_alarm_delay
{
	BLOCK transducer_block_1;
	INDEX 77;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_echo_alarm_delay
		}
	}
}
COMMAND write_trans1_echo_alarm_delay
{
	BLOCK transducer_block_1;
	INDEX 77;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_echo_alarm_delay
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_in_safety_distance			//V8H5
{
	LABEL    [trans1_in_safety_distance];
	HELP     [trans1_in_safety_distance_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE	 ENUMERATED (1)
	{
		{	0,	[trans1_in_safety_distance_0]		},	//WARNING
		{	1,	[trans1_in_safety_distance_1]		},	//ALARM
		{	2,	[trans1_in_safety_distance_2]		},	//SELF-HOLDING
		{	3,	[trans1_in_safety_distance_3]		}	//CLEAR
	}
}
COMMAND read_trans1_in_safety_distance
{
	BLOCK transducer_block_1;
	INDEX 78;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_in_safety_distance
		}
	}
}
COMMAND write_trans1_in_safety_distance
{
	BLOCK transducer_block_1;
	INDEX 78;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_in_safety_distance
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_plausibility			//V8H6
{
	LABEL    [trans1_plausibility];
	HELP     [trans1_plausibility_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE	 ENUMERATED(1)
	{
		{	0,	[trans1_plausibility_0]		},	//OFF
		{	1,	[trans1_plausibility_1]		}	//ON
	}
}
COMMAND read_trans1_plausibility
{
	BLOCK transducer_block_1;
	INDEX 79;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_plausibility
		}
	}
}
COMMAND write_trans1_plausibility
{
	BLOCK transducer_block_1;
	INDEX 79;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_plausibility
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_simulation_mode			//V9H6
{
	LABEL    [trans1_simulation_mode];
	HELP     [trans1_simulation_mode_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE	 ENUMERATED (1)
	{
		{	0,	[trans1_simulation_mode_0]		},	//OFF
		{	1,	[trans1_simulation_mode_1]		},	//LEVEL
		{	2,	[trans1_simulation_mode_2]		}	//VOLUME
//		{	3,	[trans1_simulation_mode_3]		}	//CURRENT
	}
}
COMMAND read_trans1_simulation_mode
{
	BLOCK transducer_block_1;
	INDEX 80;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_simulation_mode
		}
	}
}
COMMAND write_trans1_simulation_mode
{
	BLOCK transducer_block_1;
	INDEX 80;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_simulation_mode
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_simulated_value		//V9H7
{
	LABEL    [trans1_simulated_value];
	HELP     [trans1_simulated_value_help];
	CLASS    CONTAINED;
	HANDLING READ & WRITE;
	TYPE     FLOAT;
	VALIDITY
		IF ((1==trans1_simulation_mode)||(2==trans1_simulation_mode)){
			TRUE;
		} ELSE {
			FALSE;
		}
}
COMMAND read_trans1_simulated_value
{
	BLOCK transducer_block_1;
	INDEX 81;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_simulated_value
		}
	}
}
COMMAND write_trans1_simulated_value
{
	BLOCK transducer_block_1;
	INDEX 81;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_simulated_value
		}
		REPLY
		{
		}
	}
}

/* ----------------------------------------------------------------
 *     AI-Function Block
 * ----------------------------------------------------------------
 */

#define FUNC1_TITLE [menu_dialog_display_output]
#define DECIMAL_POINT_7_SUPPORTED
#define DECIMAL_POINT_STANDARD_SUPPORTED
//define FUNC1_PV_UNIT_LIST


#include "SIPASTAI1_200.inc"


// redefined func1_out_unit, func1_out_value and func1_out_status:
// modifications of func1_out_value are possible in MAN-mode of the blcok
VARIABLE func1_out_unit
{
	LABEL		[func_out_scale_unit];
	HELP		[func_out_scale_unit_help];
	CLASS		CONTAINED & SERVICE;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE DEFAULT_VALUE_func1_out_unit ;
		{ 44,  [ft],					[ft_help]			},
		{ 45,  [meter],					[meter_help]		},
		{ 57,  [Percent],				[Percent_help]		},
		{ 41,  [liter],					[liter_help]		},
		{ 236, [hecto_liter],			[hecto_liter_help]	},
		{ 43,  [CuMtr],					[CuMtr_help]		},
		{ 112, [CuFt],					[CuFt_help]			},
		{ 40,  [gal],					[gal_help]			},
		{ 42,  [ImpGal],				[ImpGal_help]		},
		{ 61,  [kg],					[kg_help]			},
		{ 62,  [MetTon],				[MetTon_help]		},
		{ 63,  [lb],					[lb_help]			},
		{ 64,  [ShTon],					[ShTon_help]		},
		{ 251, [none]										}
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_out_value
{
	LABEL		[func_out_value];
	HELP		[func_ai_out_value_help];
	CLASS		OUTPUT & DYNAMIC;
	TYPE		FLOAT
	{
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI;
	}
	HANDLING
		IF(func1_target_mode == 0x10)
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
}

VARIABLE func1_out_status
{
	LABEL		[func_out_status];
	HELP		[func_out_status_help];
	CLASS		OUTPUT & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
/* bad */
		{	0,	[bad_0] 		},
		{	1,	[bad_1] 		},
		{	2,	[bad_2] 		},
		{	3,	[bad_3] 		},
		{	4,	[bad_4] 		},
		{	5,	[bad_5] 		},
		{	6,	[bad_6] 		},
		{	7,	[bad_7] 		},
		{	8,	[bad_8] 		},
		{	9,	[bad_9] 		},
		{	10, [bad_10]		},
		{	11, [bad_11]		},
		{	12, [bad_12]		},
		{	13, [bad_13]		},
		{	14, [bad_14]		},
		{	15, [bad_15]		},
		{	16, [bad_16]		},
		{	17, [bad_17]		},
		{	18, [bad_18]		},
		{	19, [bad_19]		},
		{	20, [bad_20]		},
		{	21, [bad_21]		},
		{	22, [bad_22]		},
		{	23, [bad_23]		},
		{	24, [bad_24]		},
		{	25, [bad_25]		},
		{	26, [bad_26]		},
		{	27, [bad_27]		},
		{	28, [bad_28]		},
		{	29, [bad_29]		},
		{	30, [bad_30]		},
		{	31, [bad_31]		},
		{	32, [bad_32]		},
		{	33, [bad_33]		},
		{	34, [bad_34]		},
		{	35, [bad_35]		},
/* uncertain */
		{	64, [uncertain_64]	},
		{	65, [uncertain_65]	},
		{	66, [uncertain_66]	},
		{	67, [uncertain_67]	},
		{	68, [uncertain_68]	},
		{	69, [uncertain_69]	},
		{	70, [uncertain_70]	},
		{	71, [uncertain_71]	},
		{	72, [uncertain_72]	},
		{	73, [uncertain_73]	},
		{	74, [uncertain_74]	},
		{	75, [uncertain_75]	},
		{	76, [uncertain_76]	},
		{	77, [uncertain_77]	},
		{	78, [uncertain_78]	},
		{	79, [uncertain_79]	},
		{	80, [uncertain_80]	},
		{	81, [uncertain_81]	},
		{	82, [uncertain_82]	},
		{	83, [uncertain_83]	},
		{	84, [uncertain_84]	},
		{	85, [uncertain_85]	},
		{	86, [uncertain_86]	},
		{	87, [uncertain_87]	},
		{	88, [uncertain_88]	},
		{	89, [uncertain_89]	},
		{	90, [uncertain_90]	},
		{	91, [uncertain_91]	},
		{	92, [uncertain_92]	},
		{	93, [uncertain_93]	},
		{	94, [uncertain_94]	},
		{	95, [uncertain_95]	},
/* good */
		{	128,[good_128]		},
		{	129,[good_129]		},
		{	130,[good_130]		},
		{	131,[good_131]		},
		{	132,[good_132]		},
		{	133,[good_133]		},
		{	134,[good_134]		},
		{	135,[good_135]		},
		{	136,[good_136]		},
		{	137,[good_137]		},
		{	138,[good_138]		},
		{	139,[good_139]		},
		{	140,[good_140]		},
		{	141,[good_141]		},
		{	142,[good_142]		},
		{	143,[good_143]		},
		{	144,[good_144]		},
		{	145,[good_145]		},
		{	146,[good_146]		},
		{	147,[good_147]		},
		{	148,[good_148]		},
		{	149,[good_149]		},
		{	150,[good_150]		},
		{	151,[good_151]		},
		{	152,[good_152]		},
		{	153,[good_153]		},
		{	154,[good_154]		},
		{	155,[good_155]		},
		{	160,[good_160]		},
		{	161,[good_161]		},
		{	162,[good_162]		},
		{	163,[good_163]		}
	}
	HANDLING
		IF (func1_target_mode == 0x10)
		{
			READ & WRITE;
		}
		ELSE
		{
			READ;
		}
}

COMMAND read_func1_out
{
	BLOCK function_block_1;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_out_value, func1_out_status
		}
	}
}

COMMAND write_func1_out
{
	BLOCK function_block_1;
	INDEX 10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_out_value, func1_out_status
		}
		REPLY
		{
		}
	}
}

/* ================================================================
 *     Kommunikationsfehler
 * ================================================================
 */

#include "SIPAST_CommError.inc"


/** ----------------------------------------------------------------
  *   MENU Bar
  * ----------------------------------------------------------------
  */

/* Standard=Mens */
#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"

MENU Menu_Main_Specialist
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_S_Device,
		Menu_S_View,
		Menu_S_Options,
		Menu_Help
	}
}

MENU Menu_Main_Maintenance
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_M_Device,
		Menu_M_View,
		Menu_M_Options,
		Menu_Help
	}
}

/** ----------------------------------------------------------------
  *    Menu: Device
  * ----------------------------------------------------------------
  */

MENU Menu_S_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_NodeAddress,
		SEPARATOR,
		std_LoadinDevice,
		std_LoadinPC,
		SEPARATOR,
		OnlineDialog_simulation,
		OnlineDialog_reset,
		OnlineDialog_Tab_s_EH_v7,
		SEPARATOR,
		OnlineDialog_abgleich,
		OnlineDialog_stoerecho_ausblendung_fenster_ausblendung,
		OnlineDialog_linearization,
		SEPARATOR,
		OnlineDialog_write_locking
	}
}

MENU Menu_M_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_LoadinDevice,
		std_LoadinPC
	}
}

METHOD method_set
{
	LABEL       [transfer];
	HELP        [transfer_help];
	DEFINITION
	{
	}
}
METHOD std_NodeAddress
{
	LABEL		[menu_Device_NodeAddress];
	DEFINITION
	{
	}
}

METHOD std_LoadinDevice
{
	LABEL		[menu_Device_LoadinDevice];
	DEFINITION
	{
	}
}

METHOD std_LoadinPC
{
	LABEL		[menu_Device_LoadinPC];
	DEFINITION
	{
	}
}

/** ----------------------------------------------------------------
  *   Menu: View
  * ----------------------------------------------------------------
  */

MENU Menu_S_View
{
	LABEL		[menu_View];
	ITEMS
	{
		OnlineWindow_display,
		OnlineWindow_yt,
		Menu_alarm,
		OnlineWindow_diagnosis,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	}
}
OnlineWindow_S_alarm_func1_redef        LIKE MENU OnlineWindow_S_alarm_func1
{
	REDEFINE LABEL      [func1_AI];
}

MENU Menu_alarm
{
	LABEL		[menu_dialog_alarm];
	ITEMS
	{
		OnlineWindow_S_alarm_func1,
	}
}



MENU Menu_M_View
{
	LABEL		[menu_View];
	ITEMS
	{
		OnlineWindow_display,
		OnlineWindow_yt,
		Menu_alarm,
		OnlineWindow_diagnosis,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	}
}

METHOD std_Funktionsleiste
{
	LABEL		[menu_View_Toolbar];
	DEFINITION
	{
	}
}

METHOD std_Statuszeile
{
	LABEL		[menu_View_Statusbar];
	DEFINITION
	{
	}
}

METHOD std_Update
{
	LABEL		[menu_View_Update];
	DEFINITION
	{
	}
}

/** ----------------------------------------------------------------
  *    Online-Windows
  * ----------------------------------------------------------------
  */

MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_func1_out_display,
		Page_display_measure
	}
}

MENU Page_display_measure
{
	LABEL		[menu_dialog_display_measure];
	ITEMS
	{
		BarVal_pv_display,
		Group_display_primary,
		Val_std_V0H8,
		Val_std_V0H9
	}
}
MENU BarVal_pv_display
{
	LABEL		[std_V0H0];//		[trans_value];
	ITEMS
	{
		profil_par.std_V0H0,    //trans1_volume
		func1_pv_lower_range_value (READ_ONLY),
		func1_pv_upper_range_value (READ_ONLY)
	}
}
MENU Group_display_primary
{
	LABEL		[measure_value_status];
	ITEMS
	{
		profil_par.std_V0H0,    //trans1_volume
		SEPARATOR,
		profil_par.std_V3H2,	//trans1_echo_quality,
	}
}
MENU Val_std_V0H8
{
	LABEL [std_V0H8] ;
	ITEMS
	{
		profil_par.std_V0H8	(READ_ONLY)
	}
}
MENU Val_std_V0H9
{
	LABEL [std_V0H9] ;
	ITEMS
	{
		profil_par.std_V0H9	(READ_ONLY)
	}
}

MENU OnlineWindow_S_alarm
{
	LABEL		[menu_dialog_alarm];
	ITEMS
	{
		Page_alarm_sum,
		Page_hi_hi_alm,
		Page_hi_alm,
		Page_lo_alm,
		Page_lo_lo_alm
	}
}

MENU OnlineWindow_M_alarm
{
	LABEL		[menu_dialog_alarm];
	ITEMS
	{
		Page_alarm_sum
	}
}

MENU Page_alarm_sum
{
	LABEL		[menu_dialog_alarm_sum];
	ITEMS
	{
		func1_current_state_alarm_sum,
		func1_unacknowledged_state_alarm_sum,
		func1_unreported_state_alarm_sum,
		func1_disabled_state_alarm_sum
	}
}

MENU Page_hi_hi_alm
{
	LABEL		[limit_hi_hi];
	ITEMS
	{
		func1_hi_hi_alm_unacknowledged,
		func1_hi_hi_alm_state,
		func1_hi_hi_alm_subcode,
		func1_hi_hi_lim				(READ_ONLY),
		func1_hi_hi_alm_value
	}
}

MENU Page_hi_alm
{
	LABEL		[limit_hi];
	ITEMS
	{
		func1_hi_alm_unacknowledged,
		func1_hi_alm_state,
		func1_hi_alm_subcode,
		func1_hi_lim				(READ_ONLY),
		func1_hi_alm_value
	}
}

MENU Page_lo_alm
{
	LABEL		[limit_lo];
	ITEMS
	{
		func1_lo_alm_unacknowledged,
		func1_lo_alm_state,
		func1_lo_alm_subcode,
		func1_lo_lim				(READ_ONLY),
		func1_lo_alm_value
	}
}

MENU Page_lo_lo_alm
{
	LABEL		[limit_lo_lo];
	ITEMS
	{
		func1_lo_lo_alm_unacknowledged,
		func1_lo_lo_alm_state,
		func1_lo_lo_alm_subcode,
		func1_lo_lo_lim				(READ_ONLY),
		func1_lo_lo_alm_value
	}
}

MENU OnlineWindow_diagnosis
{
	LABEL		[menu_dialog_diagnosis];
	ITEMS
	{
		Page_diagnosis_general,
		Page_diagnosis_phys_block,
		Page_diagnosis_trans_block,
		Page_diagnosis_func1
	}
}

MENU Page_diagnosis_general
{
	LABEL		[menu_dialog_general];
	ITEMS
	{
		phys_tag_desc			(READ_ONLY),
		phys_manufacturer_id,
		phys_device_id,
		phys_serial_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date		(READ_ONLY),
		phys_diagnosis
	}
}

MENU Page_diagnosis_phys_block
{
	LABEL		[blk_block_object_PHYSICAL];
	ITEMS
	{
		phys_blk_object,
		phys_blk_parent_class,
		phys_blk_class,
		phys_blk_dd_reference,
		phys_blk_dd_rev,
		phys_blk_profile,
		phys_blk_profile_rev,
		phys_st_rev,
		phys_actual_mode
	}
}

MENU Page_diagnosis_trans_block
{
	LABEL		[blk_block_object_TRANSDUCER];
	ITEMS
	{
		trans1_blk_object,
		trans1_blk_parent_class,
		trans1_blk_class,
		trans1_blk_dd_reference,
		trans1_blk_dd_rev,
		trans1_blk_profile,
		trans1_blk_profile_rev,
		trans1_st_rev,
		trans1_actual_mode
	}
}

/** ----------------------------------------------------------------
  *   Online-Dialogs
  * ----------------------------------------------------------------
  */

MENU OnlineDialog_reset
{
	LABEL		[master_reset];
	HELP		[master_reset_help];
	ITEMS
	{
		profil_par.std_V9H5,	//phys_factory_reset,
		phys_diagnosis,
		method_set
	}
}

MENU OnlineDialog_abgleich
{
	LABEL		[OnlineDialog_txt_abgleich];
	HELP		[OnlineDialog_txt_abgleich_help];
	ITEMS
	{
		profil_par.std_V0H1,	//trans1_empty
		profil_par.std_V0H2,	//trans1_full
		profil_par.std_V0H3,	//trans1_application,
	}
}
/*Bi V1.34 start*/
MENU OnlineDialog_stoerecho_ausblendung_fenster_ausblendung
{
	LABEL		[OnlineDialog_txt_stoerecho_ausblendung];
	HELP		[OnlineDialog_txt_stoerecho_ausblendung_help];
	ITEMS
	{
		stoerecho_ausblendung,	
		fenster_ausblendung	//,

	}
}

MENU stoerecho_ausblendung
{
	LABEL		[OnlineDialog_txt_stoerecho_ausblendung];
	HELP		[OnlineDialog_txt_stoerecho_ausblendung_help];
	ITEMS
	{
		profil_par.std_V3H0,				//trans1_false_echo_suppression,
		profil_par.std_V3H1 (READ_ONLY),	//trans1_suppression_distance,
		meth_v3_transmit
// 		method_set
	}
}
MENU fenster_ausblendung
{
	LABEL		[OnlineDialog_txt_fenster_ausblendung];
	HELP		[OnlineDialog_txt_fenster_ausblendung_help];
	ITEMS
	{
		profil_par.std_V3H5				//trans1_window_suppression
	}
}

METHOD meth_abort
{
	DEFINITION
	{
		local_abort = 1; //Abbruch
		ACKNOWLEDGE([acknowledge_process_aborted]);
	}
}


/** ----------------------------------------------------------------
  *    Tables
  * ----------------------------------------------------------------
  */

MENU Table_Main_Specialist
{
	LABEL	DEFAULT_VALUE_phys_device_id ;
	ITEMS
	{
		Tab_s_EH_Std_Matrix,
		Tab_s_PA_Profil
	}
}

MENU Table_Main_Maintenance
{
	LABEL	DEFAULT_VALUE_phys_device_id ;
	ITEMS
	{
		Tab_m_EH_Std_Matrix,
		Tab_m_PA_Profil
	}
}

/** ----------------------------------------------------------------
  *    Table: EH Standard - BedienMatrix
  * ----------------------------------------------------------------
  */

MENU Tab_s_EH_Std_Matrix
{
	LABEL		[menu_table_EH_Std_Matrix];
	ITEMS
	{
		Tab_s_EH_v0,
		Tab_s_EH_v2,
		Tab_s_EH_v3,
		Tab_s_EH_v7,
		Tab_s_EH_v8,
		Tab_s_EH_v9,
		Tab_s_EH_vA
	}
}

MENU Tab_m_EH_Std_Matrix
{
	LABEL		[menu_table_EH_Std_Matrix];
	ITEMS
	{
		Tab_m_EH_v0
	}
}

/** ----------------------------------------------------------------
  *    Table: EH Specialist
  * ----------------------------------------------------------------
  */

MENU Tab_s_EH_v0
{
	LABEL		[menu_table_EH_v0];
	ITEMS
	{
		std_V0H0,	//trans1_volume,
		std_V0H1,	//trans1_empty,
		std_V0H2,	//trans1_full,
		std_V0H3,	//trans1_application,
		profil_par.std_V0H4,	//trans1_damping,
		profil_par.std_V0H5,	//func1_pv_lower_range_value,
		profil_par.std_V0H6,	//func1_pv_upper_range_value,
		profil_par.std_V0H7,	//trans1_fail_safe,
		profil_par.std_V0H8,	//trans1_measure_distance,
		profil_par.std_V0H9		//trans1_level
	}
}

MENU Tab_s_EH_v2
{
	LABEL		[menu_table_EH_v2];
	ITEMS
	{
		profil_par.std_V2H0,	//trans1_lin_mode,
		std_V2H1,	//trans1_lintab_no,
		std_V2H2,	//trans1_lintab_level,
		std_V2H3,	//trans1_lintab_volume,
		std_V2H5	//trans1_max_volume
	}
}

MENU Tab_s_EH_v3
{
	LABEL		[menu_table_EH_v3];
	ITEMS
	{
		std_V3H0			(READ_ONLY),	//trans1_false_echo_suppression,
		profil_par.std_V3H1	(READ_ONLY),	//trans1_suppression_distance,
		profil_par.std_V3H2,	//trans1_echo_quality,
		profil_par.std_V3H3,	//trans1_microfactor,
		profil_par.std_V3H4,	//trans1_first_echo_factor,
		profil_par.std_V3H5 (READ_ONLY),	//trans1_window_suppression,
		profil_par.std_V3H6		//trans1_zero_offset
	}
}

MENU OnlineDialog_Tab_s_EH_v7
{
	LABEL		[menu_table_EH_v7];
	ITEMS
	{
		trans1_service_layer,		//V7H0
		trans1_z_distance,			//V7H1
		trans1_71_1,
		trans1_length_of_antenna,	//V7H2
		trans1_72_1,
		trans1_modul_type,			//V7H3
		trans1_record_tvg,			//V7H4
		trans1_service_data_75,		//V7H5
		trans1_75_1,
		trans1_service_data_76,		//V7H6
		trans1_76_1,
		trans1_service_data_77,		//V7H7
		trans1_77_1,
		trans1_service_data_78,		//V7H8
		trans1_service_code			//V7H9
	}
}

MENU Tab_s_EH_v7
{
	LABEL		[menu_table_EH_v7];
	ITEMS
	{
		std_V7_hint,
		trans1_service_layer,		//V7H0
		std_V7H1,
		std_V7H1_1,
		std_V7H2,
		std_V7H2_1,
		std_V7H3,
		std_V7H4,
		std_V7H5,
		std_V7H5_1,
		std_V7H6,
		std_V7H6_1,
		std_V7H7,
		std_V7H7_1,
		std_V7H8,
		std_V7H9
	}
}

MENU Tab_s_EH_v8
{
	LABEL		[menu_table_EH_v8];
	ITEMS
	{
		profil_par.std_V8H1,	//trans1_display_min,
		profil_par.std_V8H2,	//trans1_distance_unit,
		profil_par.std_V8H3,	//trans1_echo_alarm_delay,
		profil_par.std_V8H5,	//trans1_in_safety_distance,
		profil_par.std_V8H6		//trans1_plausibility
	}
}

MENU Tab_s_EH_v9
{
	LABEL		[menu_table_EH_v9];
	ITEMS
	{
		profil_par.std_V9H0,	//phys_ms_matrix_err_code,
		profil_par.std_V9H1,	//phys_ms_matrix_last_err_code,
		profil_par.std_V9H3,	//phys_ms_device_and_software_no,
		profil_par.std_V9H4,	//phys_ms_device_bus_address,
		std_V9H5,	//phys_factory_reset,
		std_V9H6,	//trans1_simulation_mode,
		std_V9H7,	//trans1_simulated_value,
		std_V9H9,	//phys_security_locking
	}
}

MENU Tab_s_EH_vA
{
	LABEL		[menu_table_EH_vA];
	ITEMS
	{
		profil_par.std_VAH0,	//phys_tag_desc,
		profil_par.std_VAH3		//trans1_volume_unit
	}
}


/** ----------------------------------------------------------------
  *    Table: EH Maintenance
  * ----------------------------------------------------------------
  */

MENU Tab_m_EH_v0
{
	LABEL		[menu_table_EH_v0];
	ITEMS
	{
		std_V0H0,	//trans1_volume,
		std_V0H1,	//trans1_empty,
		std_V0H2,	//trans1_full,
		profil_par.std_V0H3,	//trans1_application,
		profil_par.std_V0H4,	//trans1_damping, // ????
		profil_par.std_V0H5,	//func1_pv_lower_range_value,
		profil_par.std_V0H6,	//func1_pv_upper_range_value,
		profil_par.std_V0H7,	//trans1_fail_safe,
		profil_par.std_V0H8,	//trans1_measure_distance,
		profil_par.std_V0H9		//trans1_level
	}
}

/** ----------------------------------------------------------------
  *    Table: PA Specialist
  * ----------------------------------------------------------------
  */

MENU Tab_s_PA_Profil
{
	LABEL	[menu_table_sensor_level_radar];
	ITEMS
	{
		Tab_s_ident,
		Tab_s_input,
		Tab_s_output,
		Tab_s_interface,
		Tab_s_certificates
	}
}

MENU Tab_s_ident
{
	LABEL		[menu_ident];
	ITEMS
	{
		Tab_s_ident_opunit,
		Tab_s_ident_device
	}
}



MENU Tab_s_input
{
	LABEL		[menu_input];
	ITEMS
	{
		Tab_s_input_measrange,
		Tab_s_input_measwindow,
		Tab_s_control_parameter
	}
}

MENU Tab_s_input_measrange
{
	LABEL		[menu_input_measrange];
	ITEMS
	{
		trans1_sensor_low_limit,
		trans1_sensor_high_limit
	}
}

MENU Tab_s_input_measwindow
{
	LABEL		[menu_input_measwindow];
	ITEMS
	{
		func1_pv_lower_range_value,
		func1_pv_upper_range_value
	}
}

MENU Tab_s_control_parameter
{
	LABEL [menu_control_parameter] ;
	ITEMS
	{
		trans1_volume_unit,
		trans1_distance_unit
	}
}

MENU Tab_s_output
{
	LABEL		[menu_output];
	ITEMS
	{
		Tab_s_output_signal,
		Tab_s_output_limits
	}
}

MENU Tab_s_output_signal
{
	LABEL		[menu_output_signal];
	ITEMS
	{
		func1_out_lower_range_value,
		func1_out_upper_range_value,
		func1_out_unit,
		func1_pv_ftime,
		func1_out_decimal_point
	}
}

MENU Tab_s_output_limits
{
	LABEL		[menu_output_limits];
	ITEMS
	{
		func1_lo_lo_lim,
		func1_lo_lim,
		func1_hi_lim,
		func1_hi_hi_lim,
		func1_alarm_hys
	}
}

MENU Tab_s_interface
{
	LABEL		[menu_interface];
	ITEMS
	{
		Tab_s_trim_points
		/*Tab_s_interface_simulate Bi V1.34*/
	}
}

MENU Tab_s_trim_points
{
	LABEL		[menu_trim_points];
	ITEMS
	{
		trans1_empty		(READ_ONLY),
		trans1_full			(READ_ONLY)
	}
}
/*
MENU Tab_s_interface_simulate
{
	LABEL		[menu_interface_simulate];
	ITEMS
	{
		func1_simulation_enabled	(READ_ONLY),
		func1_simulate_value		(READ_ONLY),
		func1_simulate_status		(READ_ONLY)
	}
}
Bi V1.34*/
MENU Tab_s_certificates
{
	LABEL		[menu_certificates];
	ITEMS
	{
		phys_device_certification	(READ_ONLY)
	}
}

/** ----------------------------------------------------------------
  *    Table: PA Maintenance
  * ----------------------------------------------------------------
  */

MENU Tab_m_PA_Profil
{
	LABEL	[menu_table_sensor_level_echo];
	ITEMS
	{
		Tab_m_ident
	}
}

MENU Tab_m_ident
{
	LABEL		[menu_ident];
	ITEMS
	{
		Tab_m_ident_opunit,
		Tab_m_ident_device
	}
}

MENU Tab_m_ident_opunit
{
	LABEL		[menu_ident_opunit];
	ITEMS
	{
		phys_tag_desc		(READ_ONLY),
		phys_descriptor,
		phys_message
	}
}

MENU Tab_m_ident_device
{
	LABEL		[menu_ident_device];
	ITEMS
	{
		phys_manufacturer_id,
		phys_serial_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date	(READ_ONLY),
		phys_st_rev
	}
}


COLLECTION OF VARIABLE profil_par
{
	MEMBERS
	{
		std_V0H0,	trans1_volume,					[std_V0H0];
		std_V0H1,	trans1_empty,					[std_V0H1];
		std_V0H2,	trans1_full,					[std_V0H2];
		std_V0H3,	trans1_application,				[std_V0H3];
		std_V0H4,	trans1_damping,					[std_V0H4];
		std_V0H5,	func1_pv_lower_range_value,		[std_V0H5];
		std_V0H6,	func1_pv_upper_range_value,		[std_V0H6];
		std_V0H7,	trans1_fail_safe,				[std_V0H7];
		std_V0H8,	trans1_measure_distance,		[std_V0H8];
		std_V0H9,	trans1_level,					[std_V0H9];
		std_V2H0,	trans1_lin_mode,				[std_V2H0];
		std_V2H1,	trans1_lintab_no,				[std_V2H1];
		std_V2H2,	trans1_lintab_level,			[std_V2H2];
		std_V2H3,	trans1_lintab_volume,			[std_V2H3];
		std_V2H5,	trans1_max_volume,				[std_V2H5];
		std_V3H0,	trans1_false_echo_suppression,	[std_V3H0];
		std_V3H1,	trans1_suppression_distance,	[std_V3H1];
		std_V3H2,	trans1_echo_quality,			[std_V3H2];
		std_V3H3,	trans1_microfactor,				[std_V3H3];
		std_V3H4,	trans1_first_echo_factor,		[std_V3H4];
		std_V3H5,	trans1_window_suppression,		[std_V3H5];
		std_V3H6,	trans1_zero_offset,				[std_V3H6];
		std_V7H0,	trans1_service_layer,			[std_V7H0];
		std_V7H1,	trans1_z_distance,				[std_V7H1];
		std_V7H2,	trans1_length_of_antenna,		[std_V7H2];
		std_V7H3,	trans1_modul_type,				[std_V7H3];
		std_V7H4,	trans1_record_tvg,				[std_V7H4];
		std_V7H5,	trans1_service_data_75,			[std_V7H5];
		std_V7H6,	trans1_service_data_76,			[std_V7H6];
		std_V7H7,	trans1_service_data_77,			[std_V7H7];
		std_V7H8,	trans1_service_data_78,			[std_V7H8];
		std_V7H9,	trans1_service_code,			[std_V7H9];
		std_V8H1,	trans1_display_min,				[std_V8H1];
		std_V8H2,	trans1_distance_unit,			[std_V8H2];
		std_V8H3,	trans1_echo_alarm_delay,		[std_V8H3];
		std_V8H5,	trans1_in_safety_distance,		[std_V8H5];
		std_V8H6,	trans1_plausibility,			[std_V8H6];
		std_V9H0,	phys_ms_matrix_err_code,			[std_V9H0];
		std_V9H1,	phys_ms_matrix_last_err_code,			[std_V9H1];
		std_V9H3,	phys_ms_device_and_software_no,			[std_V9H3];
		std_V9H4,	phys_ms_device_bus_address,			[std_V9H4];
		std_V9H5,	phys_factory_reset,			[std_V9H5];
		std_V9H6,	trans1_simulation_mode,			[std_V9H6];
		std_V9H7,	trans1_simulated_value,			[std_V9H7];
		std_V9H9,	phys_security_locking,			[std_V9H9];
		std_VAH0,	phys_tag_desc,					[std_VAH0];
		std_VAH3,	trans1_volume_unit,				[std_VAH3];
	}
}

VARIABLE std_V0H0
{
	LABEL       [std_V0H0];
	CLASS       LOCAL;
	TYPE        ENUMERATED
	{
		DEFAULT_VALUE 0;
		{   0,  [std_display_enum]}
	}
	HANDLING    READ;
}

VARIABLE std_V0H1
{
	LABEL       [std_V0H1];
	HELP        [trans_cal_point_lo_help];
	CLASS       LOCAL;
	TYPE        ENUMERATED
	{
		DEFAULT_VALUE 0;
		{   0,  [std_V0H3_0_enum]}
	}
	HANDLING    READ;
}

std_V0H2        LIKE VARIABLE std_V0H1
{
	REDEFINE LABEL      [std_V0H2];
	REDEFINE HELP       [trans_cal_point_hi_help];
}

VARIABLE std_V0H3
{
	LABEL       [std_V0H3];
	HELP        [trans_lev_application_help];
	CLASS       LOCAL;
	TYPE        ENUMERATED
	{
		DEFAULT_VALUE 0;
		{   0,  [std_V0H3_0_enum]}
	}
	HANDLING    READ;
}

VARIABLE std_V2H1
{
	LABEL       [std_V2H1];
	CLASS       LOCAL;
	TYPE        ENUMERATED
	{
		DEFAULT_VALUE 0;
		{   0,  [std_linearisation]}
	}
	HANDLING    READ;
}
VARIABLE std_V3H0
{
	LABEL       [std_V3H0];
	CLASS       LOCAL;
	TYPE        ENUMERATED
	{
		DEFAULT_VALUE 0;
		{   0,  [std_false_echo_suppression]}
	}
	HANDLING    READ;
}

std_V2H2        LIKE VARIABLE std_V2H1
{
	REDEFINE LABEL      [std_V2H2];
}

std_V2H3        LIKE VARIABLE std_V2H1
{
	REDEFINE LABEL      [std_V2H3];
}

std_V2H5        LIKE VARIABLE std_V2H1
{
	REDEFINE LABEL      [std_V2H5];
}
VARIABLE std_V7_hint
{
	LABEL       [std_V7_hint];
	CLASS       LOCAL;
	TYPE        ENUMERATED
	{
		DEFAULT_VALUE 0;
		{   0,  [std_V7_int_text]}
	}
	HANDLING    READ;
}
#define DEF_V7_REDEFINITIONS\
	REDEFINE CLASS LOCAL;\
	REDEFINE HANDLING READ;\
	REDEFINE POST_READ_ACTIONS {}\
	REDEFINE POST_EDIT_ACTIONS {}\

std_V7H1 LIKE VARIABLE trans1_z_distance
{
	DEF_V7_REDEFINITIONS
}
std_V7H1_1 LIKE VARIABLE trans1_71_1
{
	DEF_V7_REDEFINITIONS
}
std_V7H2 LIKE VARIABLE trans1_length_of_antenna
{
	DEF_V7_REDEFINITIONS
}
std_V7H2_1 LIKE VARIABLE trans1_72_1
{
	DEF_V7_REDEFINITIONS
}
std_V7H3 LIKE VARIABLE trans1_modul_type
{
	DEF_V7_REDEFINITIONS
}
std_V7H4 LIKE VARIABLE trans1_record_tvg
{
	DEF_V7_REDEFINITIONS
}
std_V7H5 LIKE VARIABLE trans1_service_data_75
{
	DEF_V7_REDEFINITIONS
}
std_V7H5_1 LIKE VARIABLE trans1_75_1
{
	DEF_V7_REDEFINITIONS
}
std_V7H6 LIKE VARIABLE trans1_service_data_76
{
	DEF_V7_REDEFINITIONS
}
std_V7H6_1 LIKE VARIABLE trans1_76_1
{
	DEF_V7_REDEFINITIONS
}
std_V7H7 LIKE VARIABLE trans1_service_data_77
{
	DEF_V7_REDEFINITIONS
}
std_V7H7_1 LIKE VARIABLE trans1_77_1
{
	DEF_V7_REDEFINITIONS
}
std_V7H8 LIKE VARIABLE trans1_service_data_78
{
	DEF_V7_REDEFINITIONS
}
std_V7H9 LIKE VARIABLE trans1_service_code
{
	DEF_V7_REDEFINITIONS
}

VARIABLE std_V9H5
{
	LABEL		[std_V9H5];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V9H5_enum]}
	}
	HANDLING	READ;
}

VARIABLE std_V9H6
{
	LABEL       [std_V9H6];
	CLASS       LOCAL;
	TYPE        ENUMERATED
	{
		DEFAULT_VALUE 0;
		{   0,  [std_simulation]}
	}
	HANDLING    READ;
}

std_V9H7        LIKE VARIABLE std_V9H6
{
	REDEFINE LABEL      [std_V9H7];
}

VARIABLE std_V9H9
{
	LABEL		[std_V9H9];
	HELP		[phys_write_locking_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED
	{
		DEFAULT_VALUE 0;
		{	0,	[std_V9H9_enum]}
	}
	HANDLING	READ;
}

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Write Locking                                      */
/*---------------------------------------------------------------------*/

MENU OnlineDialog_write_locking
{
	LABEL       [phys_write_locking];
	HELP        [phys_write_locking_help];
	ITEMS
	{
		profil_par.std_V9H9,	// phys_security_locking,
		method_set
	}
}
/*---------------------------------------------------------------------*/
/*	  OnlineDialog: Linearization									   */
/*---------------------------------------------------------------------*/

MENU OnlineDialog_linearization
{
	LABEL		[menu_dialog_linearization];
	ITEMS
	{
		Page_linearization_view,
		Page_linearization_input
	}
}

MENU Page_linearization_view
{
	LABEL		[menu_dialog_linearization_read];
	ITEMS
	{
		Group_linearization_status,
		profil_par.std_V2H0 (READ_ONLY),	// trans1_lin_mode
		profil_par.std_V2H1,				// trans1_lintab_no
		profil_par.std_V2H2	(READ_ONLY),	// trans1_lintab_level
		profil_par.std_V2H3 (READ_ONLY),	// trans1_lintab_volume
		profil_par.std_V2H5 (READ_ONLY),	// trans1_max_volume

		method_set
	}
}

MENU Page_linearization_input
{
	LABEL		[menu_dialog_linearization_input];
	ITEMS
	{
		Group_linearization_status,
		profil_par.std_V2H0,				// trans1_lin_mode
		profil_par.std_V2H1,				// trans1_lintab_no
		profil_par.std_V2H2,				// trans1_lintab_level
		profil_par.std_V2H3,				// trans1_lintab_volume
		profil_par.std_V2H5,				// trans1_max_volume
		method_set
	}
}

MENU Group_linearization_status
{
	LABEL		[menu_dialog_linearization_status];
	ITEMS
	{
		profil_par.std_V9H0						//phys_ms_matrix_err_code
	}
}

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Simulation                                         */
/*---------------------------------------------------------------------*/

MENU OnlineDialog_simulation
{
	LABEL		[menu_dialog_simulation];
	ITEMS
	{
		Page_simulation_input_func1,
		Page_simulation_output_func1,
		Page_simulation_v9h6_v9h7
	}
}
MENU Page_simulation_v9h6_v9h7
{
	LABEL		[menu_dialog_simulation_v9h6_v9h7];
	ITEMS
	{
		profil_par.std_V9H6,
		profil_par.std_V9H7,
		method_set
	}
}

MENU Page_simulation_input_func1
{
	LABEL		[menu_dialog_simulation_input];
	ITEMS
	{
		func1_simulation_enabled,
		Group_simulate_input_func1,
		method_set
	}
}

MENU Group_simulate_input_func1
{
	LABEL		[func_simulate_value];
	ITEMS
	{
		func1_channel (HIDDEN),
		func1_simulate_value,
		SEPARATOR,
		func1_simulate_status
	}
}

MENU Page_simulation_output_func1
{
	LABEL		[menu_dialog_simulation_output];
	ITEMS
	{
		func1_target_mode,
		func1_actual_mode,
		Group_simulate_output_func1,
		method_set
	}
}

MENU Group_simulate_output_func1
{
	LABEL		[func_out_value];
	ITEMS
	{
		func1_out_value,
		SEPARATOR,
		func1_out_status
	}
}


/**
  * ----------------------------------------------------------------
  *       Unit relations
  * ----------------------------------------------------------------
  */

UNIT UNIT_LENGTH_CONSTANT
{
	trans1_distance_unit:				//V8H2
	trans1_empty,						//V0H1
	trans1_full,						//V0H2
	trans1_measure_distance,			//V0H8
	trans1_level,						//V0H9
	trans1_lintab_level,				//V2H2
	trans1_suppression_distance,		//V3H1
	trans1_window_suppression,			//V3H5
	trans1_zero_offset,					//V3H6
	trans1_z_distance,					//V7H1
	trans1_length_of_antenna,			//V7H2
	trans1_service_data_78,				//V7H8
	trans1_71_1,
	trans1_72_1,
	trans1_75_1
}

UNIT UNIT_SIMULATION
{
// 	IF ((trans1_simulation_mode == 2) &&	//V9H6=="Volume"
// 		(trans1_lin_mode != 240))			//V2H0!="Level"
	IF (trans1_simulation_mode == 2)		//V9H6=="Volume"
	{
		trans1_volume_unit				//VAH3
	} ELSE {
		trans1_distance_unit			//V8H2
	}
	:
	trans1_simulated_value				//V9H7
}

UNIT FUNC1_PV_SCALE_UNIT
{
	IF (trans1_lin_mode == 240)
	{
		trans1_distance_unit			//V8H2
	} ELSE {
		trans1_volume_unit				//VAH3
	}
	:
	func1_pv_lower_range_value,			//V0H5
	func1_pv_upper_range_value,			//V0H6
	func1_simulate_value,
	trans1_volume						//V0H0
}


UNIT VOLUME_UNIT_REL_VAH3_1
{
	trans1_volume_unit:					//VAH3
	trans1_lintab_volume,				//V2H3
	trans1_max_volume					//V2H5
}

METHOD pre_write_upload_variables
{
	DEFINITION
	{
		ReadCommand(read_phys_security_locking);
		if  (ivar_value(phys_security_locking) == 0){
			ACKNOWLEDGE ([security_locked]);
		}
	}
}

VARIABLE loc_limit_error
{
	LABEL	"Local limit error";
	CLASS	LOCAL;
	TYPE INTEGER
	{
		DEFAULT_VALUE	0; //kein Fehler
	}
}

METHOD meth_check_lokal_limits
{
	DEFINITION
	{
		float loc_lolo, loc_lo, loc_hi, loc_hihi;
		loc_lolo = fvar_value(func1_lo_lo_lim);
		loc_lo   = fvar_value(func1_lo_lim);
		loc_hihi = fvar_value(func1_hi_hi_lim);
		loc_hi   = fvar_value(func1_hi_lim);
		iassign(loc_limit_error, 0);  // kein Fehler

		if (loc_lolo > loc_lo){
			ACKNOWLEDGE ([loclolo_bigger_loclo]);
			iassign(loc_limit_error, 1); // Fehler
		}
		if (loc_hihi < loc_hi){
			ACKNOWLEDGE ([lochihi_smaller_lochi]);
			iassign(loc_limit_error, 1); // Fehler
		}
		if (loc_hi < loc_lo){
			ACKNOWLEDGE ([lochi_smaller_loclo]);
			iassign(loc_limit_error, 1); // Fehler
		}
	}
}

METHOD meth_write_limits
{
	DEFINITION
	{
		float loc_lolo, loc_lo, loc_hi, loc_hihi;
		float act_lolo, act_lo, act_hi, act_hihi;
		loc_lolo = fvar_value(func1_lo_lo_lim);
		loc_lo   = fvar_value(func1_lo_lim);
		loc_hihi = fvar_value(func1_hi_hi_lim);
		loc_hi   = fvar_value(func1_hi_lim);
		ReadCommand(read_func1_lo_lo_lim);
		ReadCommand(read_func1_lo_lim);
		ReadCommand(read_func1_hi_hi_lim);
		ReadCommand(read_func1_hi_lim);
		act_lolo = fvar_value(func1_lo_lo_lim);
		act_lo   = fvar_value(func1_lo_lim);
		act_hihi = fvar_value(func1_hi_hi_lim);
		act_hi   = fvar_value(func1_hi_lim);

		if (0 == ivar_value(loc_limit_error)){
			fassign(func1_lo_lo_lim, loc_lolo);
			fassign(func1_lo_lim, loc_lo);
			fassign(func1_hi_hi_lim, loc_hihi);
			fassign(func1_hi_lim, loc_hi);
			if (loc_lolo > act_lo){
				WriteCommand(write_func1_lo_lim);
				WriteCommand(write_func1_lo_lo_lim);
			} else {
				WriteCommand(write_func1_lo_lo_lim);
				WriteCommand(write_func1_lo_lim);
			}
			if (loc_hihi < act_hi){
				WriteCommand(write_func1_hi_lim);
				WriteCommand(write_func1_hi_hi_lim);
			} else {
				WriteCommand(write_func1_hi_hi_lim);
				WriteCommand(write_func1_hi_lim);
			}
		}
	}
}


VARIABLE func1_hi_hi_lim
{
	LABEL		[limit_hi_hi];
	HELP		[limit_hi_hi_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE DEFAULT_VALUE_func1_hi_hi_lim;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
	POST_EDIT_ACTIONS {
		meth_check_lokal_limits
	}
}

VARIABLE func1_hi_lim
{
	LABEL		[limit_hi];
	HELP		[limit_hi_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE DEFAULT_VALUE_func1_hi_lim;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
	POST_EDIT_ACTIONS {
		meth_check_lokal_limits
	}
}

VARIABLE func1_lo_lim
{
	LABEL		[limit_lo];
	HELP		[limit_lo_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE DEFAULT_VALUE_func1_lo_lim;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
	POST_EDIT_ACTIONS {
		meth_check_lokal_limits
	}
}

VARIABLE func1_lo_lo_lim
{
	LABEL		[limit_lo_lo];
	HELP		[limit_lo_lo_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE DEFAULT_VALUE_func1_lo_lo_lim ;
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI
	}
	HANDLING	READ & WRITE;
	POST_EDIT_ACTIONS {
		meth_check_lokal_limits
	}
}

MENU upload_variables  /* Schreiben ins Feldgert */
{
	LABEL		[menu_load_to_device];
	PRE_WRITE_ACTIONS
	{
		pre_write_upload_variables,
		meth_check_lokal_limits,
		meth_write_limits
	}
	ITEMS
	{
		IF (phys_security_locking != 0){
			// E+H Matrix Objects
			profil_par.std_V0H4,	//trans1_damping,
			profil_par.std_V0H5,	//func1_pv_lower_range_value,
			profil_par.std_V0H6,	//func1_pv_upper_range_value,
			profil_par.std_V0H7,	//trans1_fail_safe,
			profil_par.std_V2H0,	//trans1_lin_mode,
			profil_par.std_V3H3,	//trans1_microfactor,
			profil_par.std_V3H4,	//trans1_first_echo_factor,
			/*profil_par.std_V3H5,	Bi V1.34*///trans1_window_suppression,
			profil_par.std_V3H6,	//trans1_zero_offset
			profil_par.std_V8H1,	//trans1_display_min,
			profil_par.std_V8H2,	//trans1_distance_unit,
			profil_par.std_V8H3,	//trans1_echo_alarm_delay,
			profil_par.std_V8H5,	//trans1_in_safety_distance,
			profil_par.std_V8H6,	//trans1_plausibility
			profil_par.std_V9H1,	//phys_ms_matrix_last_err_code,
			profil_par.std_VAH0,	//phys_tag_desc,
			profil_par.std_VAH3,	//trans1_volume_unit
			//PA 2.0 - Profile Objects
			phys_tag_desc,
			phys_descriptor,
			phys_message,
			phys_install_date,
			func1_pv_lower_range_value,
			func1_pv_upper_range_value,
			func1_out_lower_range_value,
			func1_out_upper_range_value,
			func1_out_unit,
			func1_pv_ftime,
			func1_out_decimal_point,
			func1_lo_lo_lim,
			func1_lo_lim,
			func1_hi_lim,
			func1_hi_hi_lim,
			func1_alarm_hys
		}
	}
}

MENU download_variables  /* Lesen aus Feldgert */
{
	LABEL   [menu_load_to_PC];
	ITEMS
	{
		// E+H Matrix Objects
		profil_par.std_V0H3,	//trans1_application,
		profil_par.std_V0H4,	//trans1_damping,
		profil_par.std_V0H5,	//func1_pv_lower_range_value,
		profil_par.std_V0H6,	//func1_pv_upper_range_value,
		profil_par.std_V0H7,	//trans1_fail_safe,
		profil_par.std_V0H8,	//trans1_measure_distance,
		profil_par.std_V0H9,	//trans1_level
		profil_par.std_V2H0,	//trans1_lin_mode,
		profil_par.std_V3H0,	//trans1_false_echo_suppression,
		profil_par.std_V3H1,	//trans1_suppression_distance,
		profil_par.std_V3H2,	//trans1_echo_quality,
		profil_par.std_V3H3,	//trans1_microfactor,
		profil_par.std_V3H4,	//trans1_first_echo_factor,
		profil_par.std_V3H5,	//trans1_window_suppression,
		profil_par.std_V3H6,	//trans1_zero_offset
		trans1_service_layer,		//V7H0

		trans1_z_distance,			//V7H1
		trans1_71_1,
		trans1_length_of_antenna,	//V7H2
		trans1_72_1,
		trans1_modul_type,			//V7H3
		trans1_record_tvg,			//V7H4
		trans1_service_data_75,		//V7H5
		trans1_75_1,
		trans1_service_data_76,		//V7H6
		trans1_76_1,
		trans1_service_data_77,		//V7H7
		trans1_77_1,
		trans1_service_data_78,		//V7H8
		trans1_service_code,		//V7H9

		profil_par.std_V8H1,	//trans1_display_min,
		profil_par.std_V8H2,	//trans1_distance_unit,
		profil_par.std_V8H3,	//trans1_echo_alarm_delay,
		profil_par.std_V8H5,	//trans1_in_safety_distance,
		profil_par.std_V8H6,	//trans1_plausibility
		profil_par.std_V9H0,	//phys_ms_matrix_err_code,
		profil_par.std_V9H1,	//phys_ms_matrix_last_err_code,
		profil_par.std_V9H3,	//phys_ms_device_and_software_no,
		profil_par.std_V9H4,	//phys_ms_device_bus_address,
		profil_par.std_V9H9,	//phys_security_locking
		profil_par.std_VAH0,	//phys_tag_desc,
		profil_par.std_VAH3,	//trans1_volume_unit
		//PA 2.0 - Profile Objects
		phys_tag_desc,
		phys_descriptor,
		phys_message,
		phys_manufacturer_id,
		phys_serial_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date,
		phys_st_rev,
		trans1_sensor_low_limit,
		trans1_sensor_high_limit,
		func1_pv_lower_range_value,
		func1_pv_upper_range_value,
		func1_out_lower_range_value,
		func1_out_upper_range_value,
		func1_out_unit,
		func1_pv_ftime,
		func1_out_decimal_point,
		func1_lo_lo_lim,
		func1_lo_lim,
		func1_hi_lim,
		func1_hi_hi_lim,
		func1_alarm_hys,
		phys_device_certification
	}
}
METHOD meth_write_79
{
	DEFINITION
	{
		WriteCommand (write_trans1_service_code);
	}
}

VARIABLE trans1_71_1				      //V7H1_1
{
	LABEL    [std_V7H1_1];
	HELP     [std_V7H1_1];
	CLASS    CONTAINED;
	HANDLING DEF_ACCESS_711_712
	TYPE     FLOAT
	{
		DEFAULT_VALUE 0.0;
		MIN_VALUE -19999;
		MAX_VALUE  19999;
	}
	VALIDITY
		IF (trans1_service_layer != 0)
		{
			TRUE;
		} ELSE {
			FALSE;
		}
	PRE_WRITE_ACTIONS
	{
		meth_write_79
	}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H1_1
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H1_1
	}
}
METHOD meth_update_std_V7H1_1
{
	DEFINITION
	{
		std_V7H1_1=fvar_value(trans1_71_1);
	}
}

COMMAND read_trans1_71_1
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_71_1
		}
	}
}
COMMAND write_trans1_71_1
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_71_1
		}
		REPLY
		{
		}
	}
}
VARIABLE trans1_72_1					//V7H2_2
{
	LABEL    [std_V7H2_1];
	HELP     [std_V7H2_1];
	CLASS    CONTAINED;
	HANDLING DEF_ACCESS_711_712
	TYPE     FLOAT
	{
		DEFAULT_VALUE 0.0;
		MIN_VALUE -19999;
		MAX_VALUE  19999;
	}
	VALIDITY
		IF (trans1_service_layer != 0)
		{
			TRUE;
		} ELSE {
			FALSE;
		}
	PRE_WRITE_ACTIONS
	{
		meth_write_79
	}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H2_1
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H2_1
	}
}
METHOD meth_update_std_V7H2_1
{
	DEFINITION
	{
		std_V7H2_1=fvar_value(trans1_72_1);
	}
}

COMMAND read_trans1_72_1
{
	BLOCK transducer_block_1;
	INDEX 68;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_72_1
		}
	}
}
COMMAND write_trans1_72_1
{
	BLOCK transducer_block_1;
	INDEX 68;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_72_1
		}
		REPLY
		{
		}
	}
}
VARIABLE trans1_75_1					//V7H5_1
{
	LABEL    [trans1_service_data_75];
	HELP     [trans1_service_data_75];
	CLASS    CONTAINED & DYNAMIC;
	HANDLING DEF_ACCESS_71_2_79
	TYPE     FLOAT
	{
		DEFAULT_VALUE 0.0;
	}
	VALIDITY
		IF (trans1_service_layer != 0)
		{
			TRUE;
		} ELSE {
			FALSE;
		}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H5_1
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H5_1
	}
}
METHOD meth_update_std_V7H5_1
{
	DEFINITION
	{
		std_V7H5_1=fvar_value(trans1_75_1);
	}
}

COMMAND read_trans1_75_1
{
	BLOCK transducer_block_1;
	INDEX 71;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_75_1
		}
	}
}
COMMAND write_trans1_75_1
{
	BLOCK transducer_block_1;
	INDEX 71;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_75_1
		}
		REPLY
		{
		}
	}
}

VARIABLE trans1_76_1					//V7H6_1
{
	LABEL    [trans1_service_data_76];
	HELP     [trans1_service_data_76];
	CLASS    CONTAINED & CONTAINED;
	HANDLING READ;
	TYPE     FLOAT
	{
		DEFAULT_VALUE 0.0;
	}
	VALIDITY
		IF (trans1_service_layer != 0)
		{
			TRUE;
		} ELSE {
			FALSE;
		}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H6_1
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H6_1
	}
}
METHOD meth_update_std_V7H6_1
{
	DEFINITION
	{
		std_V7H6_1=fvar_value(trans1_76_1);
	}
}

COMMAND read_trans1_76_1
{
	BLOCK transducer_block_1;
	INDEX 72;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_76_1
		}
	}
}
VARIABLE trans1_77_1				//V7H7_1
{
	LABEL    [trans1_service_data_77];
	HELP     [trans1_service_data_77];
	CLASS    CONTAINED & DYNAMIC;
	HANDLING READ;
	TYPE     FLOAT
	{
		DEFAULT_VALUE 0.0;
	}
	VALIDITY
		IF (trans1_service_layer != 0)
		{
			TRUE;
		} ELSE {
			FALSE;
		}
	POST_READ_ACTIONS
	{
		meth_update_std_V7H7_1
	}
	POST_EDIT_ACTIONS
	{
		meth_update_std_V7H7_1
	}
}
METHOD meth_update_std_V7H7_1
{
	DEFINITION
	{
		std_V7H7_1=fvar_value(trans1_77_1);
	}
}
COMMAND read_trans1_77_1
{
	BLOCK transducer_block_1;
	INDEX 73;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_77_1
		}
	}
}

